@@ -1,6 +1,6 @@
 import pytest
 
-from ..utils.project import project_root
+from ..utils.project import ATOMKRAFT_INTERNAL_DIR, project_root
 from . import CHAIN_CONFIG_FILE
 from .testnet import Testnet
 
@@ -9,7 +9,7 @@ from .testnet import Testnet
 def testnet():
     testnet = Testnet.load_toml(
         project_root() / CHAIN_CONFIG_FILE,
-        data_dir=project_root() / ".atomkraft",
+        data_dir=project_root() / ATOMKRAFT_INTERNAL_DIR,
         keep=True,
         overwrite=True,
     )
