@@ -2,6 +2,10 @@ import os
 from pathlib import Path
 from typing import Union
 
+ATOMKRAFT_INTERNAL_DIR = ".atomkraft"
+
+ATOMKRAFT_VAL_DIR_PREFIX = "val_"
+
 
 class NoProjectError(RuntimeError):
     def __init__(self) -> None:
@@ -14,7 +18,7 @@ def project_root() -> Path:
         if (
             (cwd / "pyproject.toml").exists()
             and (cwd / "atomkraft.toml").exists()
-            and (cwd / ".atomkraft" / "config.toml").exists()
+            and (cwd / ATOMKRAFT_INTERNAL_DIR / "config.toml").exists()
         ):
             return cwd
         cwd = cwd.parent
